# yawebview
yawebview(Yet Another Webview library) that helps you build cross platform GUI for python applications using web technologies(HTML, JavaScript and CSS).

yawebview is tailor-made for [YADE](https://gitlab.com/webyfy/iot/e-gurukul/yade) development. yawebview contains common code that we were going to write anyway.

